Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(342)

Unified Diff: net/proxy/proxy_server_unittest.cc

Issue 3388021: Change the meaning of the command-line flag --proxy-server="socks://foo" to i... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 10 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/proxy/proxy_server.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/proxy/proxy_server_unittest.cc
===================================================================
--- net/proxy/proxy_server_unittest.cc (revision 60502)
+++ net/proxy/proxy_server_unittest.cc (working copy)
@@ -114,22 +114,22 @@
"SOCKS5 foopy:10"
},
// SOCKS proxy URIs (should default to SOCKS4)
{
"socks://foopy", // No port.
- "socks4://foopy:1080",
- net::ProxyServer::SCHEME_SOCKS4,
+ "socks5://foopy:1080",
+ net::ProxyServer::SCHEME_SOCKS5,
"foopy",
1080,
- "SOCKS foopy:1080"
+ "SOCKS5 foopy:1080"
},
{
"socks://foopy:10",
- "socks4://foopy:10",
- net::ProxyServer::SCHEME_SOCKS4,
+ "socks5://foopy:10",
+ net::ProxyServer::SCHEME_SOCKS5,
"foopy",
10,
- "SOCKS foopy:10"
+ "SOCKS5 foopy:10"
},
// HTTPS proxy URIs:
« no previous file with comments | « net/proxy/proxy_server.cc ('k') | no next file » | no next file with comments »
@@ -114,22 +114,22 @@
"SOCKS5 foopy:10"
},
- // SOCKS proxy URIs (should default to SOCKS4)
+ // SOCKS proxy URIs (should default to SOCKS5)
{
"socks://foopy", // No port.

Powered by Google App Engine
This is Rietveld 408576698